AdminModel

Derive Macro AdminModel 

#[derive(AdminModel)]
Implements the AdminModel trait for a struct.

This is a simple method for adding a database model to the admin panel. Note that in order for this derive macro to work, the structure must implement Model and Form traits. These can also be derived using the #[model] and #[derive(Form)] attributes.