#[filter_fn]Expand description
A macro attribute to write custom filters for askama templates.
Please see askama’s book for more information.
#[filter_fn]A macro attribute to write custom filters for askama templates.
Please see askama’s book for more information.