Module config

Module config 

Configuration data for the project.

This module contains the configuration data for the project. This includes stuff such as the secret key used for signing cookies, database connection settings, whether the debug mode is enabled, and other project-specific configuration data.

The main struct in this module is ProjectConfig, which contains all the configuration data for the project. After creating an instance using ProjectConfig::from_toml or ProjectConfigBuilder, it can be passed to the Bootstrapper.

Structs

CacheConfigcache
Configuration for the cache system.
CacheConfigBuilder
Builder for CacheConfig.
CacheStoreConfigcache
Configuration for the cache store backend.
CacheStoreConfigBuilder
Builder for CacheStoreConfig.
CacheUrlcache
A URL for caches.
DatabaseConfigdb
The configuration for the database.
DatabaseConfigBuilder
Builder for DatabaseConfig.
DatabaseUrldb
A URL for the database.
EmailConfigemail
Configuration for the email system.
EmailConfigBuilder
Builder for EmailConfig.
EmailTransportConfigemail
Configuration structure for email transport settings.
EmailTransportConfigBuilder
Builder for EmailTransportConfig.
EmailUrlemail
A URL for email services.
LiveReloadMiddlewareConfig
The configuration for the live reload middleware.
LiveReloadMiddlewareConfigBuilder
Builder for LiveReloadMiddlewareConfig.
MiddlewareConfig
The configuration for the middlewares.
MiddlewareConfigBuilder
Builder for MiddlewareConfig.
ProjectConfig
The configuration for a project.
ProjectConfigBuilder
Builder for ProjectConfig.
SecretKey
A secret key.
SessionMiddlewareConfig
The configuration for the session middleware.
SessionMiddlewareConfigBuilder
Builder for SessionMiddlewareConfig.
SessionStoreConfig
The configuration for the session store.
SessionStoreConfigBuilder
Builder for SessionStoreConfig.
StaticFilesConfig
The configuration for the static files. The configuration for serving static files. This configuration controls how static files (like CSS, JavaScript, images, etc.) are served by the application. It allows you to customize the URL prefix, caching behavior, and URL rewriting strategy for static assets.
StaticFilesConfigBuilder
Builder for StaticFilesConfig.

Enums

AuthBackendConfig
The configuration for the authentication backend.
CacheStoreTypeConfigcache
The type of cache store backend to use.
CacheTypecache
A structure that holds the type of Cache.
EmailTransportTypeConfigemail
The type of email transport backend to use.
Expiry
Session expiry configuration. The Expiry attribute of a cookie determines its lifetime. When not explicitly configured, cookies default to OnSessionEnd behavior.
ParseCacheTypeError
An error returned when parsing a CacheType from a string.
SameSite
The SameSite attribute of a cookie determines how strictly browsers send cookies on cross-site requests. When not explicitly configured, it defaults to Strict, which provides the most restrictive security posture.
SessionStoreTypeConfig
The configuration for the session store type.
StaticFilesPathRewriteMode
Configuration for the URL rewriting of static files.
Timeout
Expiration policy for cached values.