pub struct EmailConfig {
pub transport: EmailTransportConfig,
}Available on crate feature
email only.Expand description
Configuration for the email system.
This specifies all the configuration options for sending emails.
Examples
use cot::config::{EmailConfig, EmailTransportConfig, EmailTransportTypeConfig};
let config = EmailConfig::builder()
.transport(
EmailTransportConfig::builder()
.transport_type(EmailTransportTypeConfig::Console)
.build(),
)
.build();
assert_eq!(
config.transport.transport_type,
EmailTransportTypeConfig::Console
);Fields
transport: EmailTransportConfigThe type of email transport backend to use.
This determines which type of email transport backend to use (console
or smtp) along with its configuration options.
Examples
use cot::config::{EmailConfig, EmailTransportConfig, EmailTransportTypeConfig};
let config = EmailConfig::builder()
.transport(
EmailTransportConfig::builder()
.transport_type(EmailTransportTypeConfig::Console)
.build(),
)
.build();
assert_eq!(
config.transport.transport_type,
EmailTransportTypeConfig::Console
);TOML Configuration
[email.transport]
type = "console"
# Or for SMTP:
# [email.transport]
# type = "smtp"
# auth_id = "your_auth_id"
# secret = "your_secret"
# mechanism = "plain" # or "login", "xoauth2"
# server = "smtp.gmail.com" # or "localhost"Implementations
Sourceimpl EmailConfig
impl EmailConfig
Sourcepub fn builder() -> EmailConfigBuilder
pub fn builder() -> EmailConfigBuilder
Create a new EmailConfigBuilder to build an
EmailConfig.
Examples
use cot::config::EmailConfig;
let config = EmailConfig::builder().build();Trait Implementations
Sourceimpl Clone for EmailConfig
impl Clone for EmailConfig
Sourcefn clone(&self) -> EmailConfig
fn clone(&self) -> EmailConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EmailConfig
impl Debug for EmailConfig
Sourceimpl Default for EmailConfig
impl Default for EmailConfig
Sourceimpl<'de> Deserialize<'de> for EmailConfigwhere
EmailConfig: Default,
impl<'de> Deserialize<'de> for EmailConfigwhere
EmailConfig: Default,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for EmailConfig
Sourceimpl PartialEq for EmailConfig
impl PartialEq for EmailConfig
Sourceimpl Serialize for EmailConfig
impl Serialize for EmailConfig
impl StructuralPartialEq for EmailConfig