#[non_exhaustive]pub enum DatabaseError {
DatabaseEngineError(Error),
QueryBuildingError(Error),
TypeMismatch {
expected: String,
found: String,
},
ValueDecode(Box<dyn Error + Send + Sync + 'static>),
MigrationError(MigrationEngineError),
RecordNotFound {
primary_key: DbValue,
},
ForeignKeyNotFound,
UniqueViolation,
BulkInsertModelTooLarge {
field_count: usize,
limit: usize,
},
BulkInsertNoValueColumns,
BulkInsertReturnDataInvalid {
expected: usize,
actual: usize,
},
}Available on crate feature
db only.Expand description
An error that can occur when interacting with the database.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
DatabaseEngineError(Error)
Database engine error.
QueryBuildingError(Error)
Error when building query.
TypeMismatch
Type mismatch in database value.
ValueDecode(Box<dyn Error + Send + Sync + 'static>)
Error when decoding database value.
MigrationError(MigrationEngineError)
Error when applying migrations.
RecordNotFound
A record could not be found in the database.
ForeignKeyNotFound
Foreign Key could not be retrieved from the database because the record was not found.
UniqueViolation
Error when a unique constraint is violated in the database.
BulkInsertModelTooLarge
Single model has more fields than database parameter limit.
Fields
BulkInsertNoValueColumns
Attempted bulk create with a model that only contains Auto fields.
BulkInsertReturnDataInvalid
Data returned by the bulk insert does not match the expected number of rows.
Implementations
Sourceimpl DatabaseError
impl DatabaseError
Sourcepub fn value_decode(error: impl Error + 'static + Send + Sync) -> Self
pub fn value_decode(error: impl Error + 'static + Send + Sync) -> Self
Creates a new database error from a value decode error.