Enum DbFieldValue

pub enum DbFieldValue {
    Auto,
    Value(DbValue),
}
Available on crate feature db only.
Represents a value for a field in the database.

This enum is used to indicate whether a field’s value should be explicitly included in a query or automatically generated by the database.

  • DbFieldValue::Auto: The field’s value will be automatically generated by the database and not included in the query.
  • DbFieldValue::Value: A specific value is provided and included in the query.

Examples

Using DbFieldValue to represent a field value in an insert operation:

use cot::db::{DbFieldValue, DbValue};

// Simulate a database field with a specific value
let value_field = DbFieldValue::Value(DbValue::Int(Some(42)));
assert!(value_field.is_value());
assert!(!value_field.is_auto());

// Simulate a database field with an auto-incremented value
let auto_field = DbFieldValue::Auto;
assert!(auto_field.is_auto());
assert!(!auto_field.is_value());

// Extract the value from a DbFieldValue::Value variant
if let DbFieldValue::Value(val) = value_field {
    println!("Field value: {:?}", val);
}

// Attempting to unwrap an auto-generated field will panic:
// auto_field.unwrap_value(); // This would panic!

Variants



Auto

The value should be automatically generated by the database and not included in the query.

Examples

use cot::db::{DbFieldValue, DbValue};

let auto_field = DbFieldValue::Auto;
assert!(auto_field.is_auto());


Value(DbValue)

A value that should be included in the query.

Examples

use cot::db::{DbFieldValue, DbValue};

let value_field = DbFieldValue::Value(DbValue::Int(Some(42)));
assert!(value_field.is_value());
assert_eq!(value_field.unwrap_value(), DbValue::Int(Some(42)));

Implementations

Source

impl DbFieldValue

pub fn is_auto(&self) -> bool

Returns true if the field value is automatically generated by the database.

Examples
use cot::db::DbFieldValue;

let auto_field = DbFieldValue::Auto;
assert!(auto_field.is_auto());
pub fn is_value(&self) -> bool

Returns true if the field value is explicitly provided and included in the query.

Examples
use cot::db::{DbFieldValue, DbValue};

let value_field = DbFieldValue::Value(DbValue::Int(Some(42)));
assert!(value_field.is_value());
pub fn unwrap_value(self) -> DbValue

Returns the value of the field if it is explicitly provided and included in the query.

Panics

This method will panic if the field value is automatically generated by the database.

Examples
use cot::db::{DbFieldValue, DbValue};

let value_field = DbFieldValue::Value(DbValue::Int(Some(42)));
assert_eq!(value_field.unwrap_value(), DbValue::Int(Some(42)));
pub fn expect_value(self, message: &str) -> DbValue

Returns the value of the field if it is explicitly provided and included in the query.

Panics

This method will panic with given message if the field value is automatically generated by the database.

Examples
use cot::db::{DbFieldValue, DbValue};

let value_field = DbFieldValue::Value(DbValue::Int(Some(42)));
assert_eq!(
    value_field.expect_value("expected value"),
    DbValue::Int(Some(42))
);