pub struct MigrationDependency { /* private fields */ }Available on crate feature
db only.Expand description
A migration dependency: a relationship between two migrations that tells the migration engine which migrations need to be applied before others.
Implementations
Sourceimpl MigrationDependency
impl MigrationDependency
Sourcepub const fn migration(app: &'static str, migration: &'static str) -> Self
pub const fn migration(app: &'static str, migration: &'static str) -> Self
Creates a dependency on another migration.
This ensures that the migration engine will apply the migration with given app and migration name before the current migration.
Sourcepub const fn model(app: &'static str, table_name: Identifier) -> Self
pub const fn model(app: &'static str, table_name: Identifier) -> Self
Creates a dependency on a model.
This ensures that the migration engine will apply the migration that creates the model with the given app and table name before the current migration.