DynMigration

Trait DynMigration 

pub trait DynMigration {
    // Required methods
    fn app_name(&self) -> &str;
    fn name(&self) -> &str;
    fn dependencies(&self) -> &[MigrationDependency];
    fn operations(&self) -> &[Operation];
}
Available on crate feature db only.
A trait for defining a migration that can be dynamically applied.

This is mostly useful for use in the MigrationEngine to allow migrations to be dynamically loaded from multiple apps. This can also be used to implement custom migration loading logic, or to implement migrations that are not statically defined.

This trait has a blanket implementation for types that implement Migration.

Required Methods

fn app_name(&self) -> &str

The name of the app that this migration belongs to.

fn name(&self) -> &str

The name of the migration.

fn dependencies(&self) -> &[MigrationDependency]

The list of dependencies of the migration.

fn operations(&self) -> &[Operation]

The list of operations to apply in the migration.