Struct Query

pub struct Query<T> { /* private fields */ }
Available on crate feature db only.
A query that can be executed on a database. Can be used to filter, update, or delete rows.

Example

use cot::db::model;
use cot::db::query::Query;

#[model]
struct User {
    #[model(primary_key)]
    id: i32,
    name: String,
    age: i32,
}

let query = Query::<User>::new();

Implementations

Source

impl<T: Model> Query<T>

pub fn new() -> Self

Create a new query.

Example
use cot::db::model;
use cot::db::query::Query;

#[model]
struct User {
    #[model(primary_key)]
    id: i32,
    name: String,
    age: i32,
}

let query = Query::<User>::new();
pub fn filter(&mut self, filter: Expr) -> &mut Self

Set the filter expression for the query.

Example
use cot::db::model;
use cot::db::query::{Expr, Query};

#[model]
struct User {
    #[model(primary_key)]
    id: i32,
    name: String,
    age: i32,
}

let query = Query::<User>::new().filter(Expr::eq(Expr::field("name"), Expr::value("John")));
pub fn limit(&mut self, limit: u64) -> &mut Self

Set the limit for the query.

Example
use cot::db::model;
use cot::db::query::{Expr, Query};

#[model]
struct User {
    #[model(primary_key)]
    id: i32,
    name: String,
    age: i32,
}

let query = Query::<User>::new().limit(10);
pub fn offset(&mut self, offset: u64) -> &mut Self

Set the offset for the query.

Example
use cot::db::model;
use cot::db::query::{Expr, Query};

#[model]
struct User {
    #[model(primary_key)]
    id: i32,
    name: String,
    age: i32,
}

let query = Query::<User>::new().offset(10);
pub async fn all<DB: DatabaseBackend>(&self, db: &DB) -> Result<Vec<T>>

Execute the query and return all results.

Errors

Returns an error if the query fails.

pub async fn get<DB: DatabaseBackend>(&self, db: &DB) -> Result<Option<T>>

Execute the query and return the first result.

Errors

Returns an error if the query fails.

pub async fn count(&self, db: &Database) -> Result<u64>

Execute the query and return the number of results.

Errors

Returns an error if the query fails.

pub async fn exists<DB: DatabaseBackend>(&self, db: &DB) -> Result<bool>

Execute the query and check if any results exist.

Errors

Returns an error if the query fails.

pub async fn delete<DB: DatabaseBackend>( &self, db: &DB, ) -> Result<StatementResult>

Delete all rows that match the query.

Errors

Returns an error if the query fails.