DynErrorPageHandler

Struct DynErrorPageHandler 

pub struct DynErrorPageHandler { /* private fields */ }
A type-erased wrapper around an error page handler.

This struct allows storing different types of error page handlers in a homogeneous collection or service. It implements Clone and can be used with Cot’s error handling infrastructure.

Implementations

Source

impl DynErrorPageHandler

pub fn new<HandlerParams, H>(handler: H) -> Self
where HandlerParams: 'static, H: ErrorPageHandler<HandlerParams> + Send + Sync + 'static,

Creates a new DynErrorPageHandler from a concrete error page handler.

This method wraps a concrete error page handler in a type-erased wrapper, allowing it to be used in crate::project::Project::error_handler.

Examples
use cot::Project;
use cot::error::handler::{DynErrorPageHandler, RequestError};
use cot::html::Html;
use cot::response::IntoResponse;

struct MyProject;
impl Project for MyProject {
    fn error_handler(&self) -> DynErrorPageHandler {
        DynErrorPageHandler::new(error_handler)
    }
}

// This function automatically implements ErrorPageHandler
async fn error_handler(error: RequestError) -> impl IntoResponse {
    Html::new(format!("An error occurred: {error}")).with_status(error.status_code())
}