#[non_exhaustive]pub enum FormError {
#[non_exhaustive] RequestError {
error: Box<Error>,
},
#[non_exhaustive] MultipartError {
error: FormFieldValueError,
},
}Expand description
Error occurred while processing a form.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
#[non_exhaustive]RequestError
An error occurred while processing the request, before validating the form data.
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.
#[non_exhaustive]MultipartError
The underlying error that occurred during multipart form processing.
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.

error: FormFieldValueErrorThe underlying error that occurred during multipart form processing.