pub struct EmailFieldOptions {
pub max_length: Option<u32>,
pub min_length: Option<u32>,
}Expand description
Custom options for EmailField
Fields
max_length: Option<u32>The maximum length of the field used to set the maxlength attribute
in the HTML input element.
min_length: Option<u32>The minimum length of the field used to set the minlength attribute
in the HTML input element.