Json

Struct Json 

pub struct Json<D>(pub D);
Available on crate feature json only.
A type that represents JSON content.

Note that this is just a newtype wrapper around data and does not provide any content validation. It is primarily useful as a request extractor and response type for REST-ful endpoints.

Examples

use cot::json::Json;

let Json(data) = Json("content");
assert_eq!(data, "content");

Tuple Fields

0: D