pub struct NoApi<T>(pub T);Available on crate feature
openapi only.Expand description
A wrapper type that allows using non-OpenAPI handlers and request parameters in OpenAPI routes.
If you need an extractor or a handler that does not implement
AsApiOperation/ApiOperationPart, you can wrap it in a NoApi to
indicate that it should just be ignored during OpenAPI generation.
Examples
use cot::openapi::NoApi;
use cot::request::RequestHead;
use cot::request::extractors::FromRequestHead;
use cot::response::Response;
use cot::router::Route;
use cot::router::method::openapi::api_get;
struct MyExtractor;
impl FromRequestHead for MyExtractor {
async fn from_request_head(head: &RequestHead) -> cot::Result<Self> {
// ...
}
}
async fn handler(NoApi(extractor): NoApi<MyExtractor>) -> cot::Result<Response> {
// MyExtractor doesn't have to implement ApiOperationPart and
// doesn't show up in the OpenAPI spec
}
let router =
cot::router::Router::with_urls([Route::with_api_handler("/with_api", api_get(handler))]);use cot::openapi::NoApi;
use cot::response::Response;
use cot::router::Route;
use cot::router::method::openapi::api_get;
async fn handler_with_openapi() -> cot::Result<Response> {
// ...
}
async fn handler_without_openapi() -> cot::Result<Response> {
// ...
}
let router = cot::router::Router::with_urls([Route::with_api_handler(
"/with_api",
// POST will be ignored in OpenAPI spec
api_get(handler_with_openapi).post(NoApi(handler_without_openapi)),
)]);Tuple Fields
0: TTrait Implementations
Sourceimpl<T> ApiOperationPart for NoApi<T>
impl<T> ApiOperationPart for NoApi<T>
Sourcefn modify_api_operation(
operation: &mut Operation,
route_context: &RouteContext<'_>,
schema_generator: &mut SchemaGenerator,
)
fn modify_api_operation( operation: &mut Operation, route_context: &RouteContext<'_>, schema_generator: &mut SchemaGenerator, )
Modify the OpenAPI operation object. Read more
Sourceimpl<T> AsApiOperation for NoApi<T>
impl<T> AsApiOperation for NoApi<T>
Sourcefn as_api_operation(
&self,
_route_context: &RouteContext<'_>,
_schema_generator: &mut SchemaGenerator,
) -> Option<Operation>
fn as_api_operation( &self, _route_context: &RouteContext<'_>, _schema_generator: &mut SchemaGenerator, ) -> Option<Operation>
Returns the OpenAPI operation for the route. Read more
impl<T: Copy> Copy for NoApi<T>
impl<T: Eq> Eq for NoApi<T>
Sourceimpl<T: FromRequest> FromRequest for NoApi<T>
impl<T: FromRequest> FromRequest for NoApi<T>
Sourceasync fn from_request(head: &RequestHead, body: Body) -> Result<Self>
async fn from_request(head: &RequestHead, body: Body) -> Result<Self>
Extracts data from the request. Read more
Sourceimpl<T: FromRequestHead> FromRequestHead for NoApi<T>
impl<T: FromRequestHead> FromRequestHead for NoApi<T>
Sourceasync fn from_request_head(head: &RequestHead) -> Result<Self>
async fn from_request_head(head: &RequestHead) -> Result<Self>
Extracts data from the request head. Read more
Sourceimpl<T: Ord> Ord for NoApi<T>
impl<T: Ord> Ord for NoApi<T>
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl<T: PartialOrd> PartialOrd for NoApi<T>
impl<T: PartialOrd> PartialOrd for NoApi<T>
Sourceimpl<HandlerParams, H> RequestHandler<HandlerParams> for NoApi<H>where
H: RequestHandler<HandlerParams>,
impl<HandlerParams, H> RequestHandler<HandlerParams> for NoApi<H>where
H: RequestHandler<HandlerParams>,
impl<T: PartialEq> StructuralPartialEq for NoApi<T>