pub enum Uninitialized {}Expand description
First phase of bootstrapping a Cot project, the uninitialized phase.
See also
See the details about the different bootstrap phases in the
BootstrapPhase trait documentation.