Configuration data for the project.
This module contains the configuration data for the project. This includes stuff such as the secret key used for signing cookies, database connection settings, whether the debug mode is enabled, and other project-specific configuration data.
The main struct in this module is ProjectConfig, which contains all the
configuration data for the project. After creating an instance using
ProjectConfig::from_toml or ProjectConfigBuilder, it can be passed
to the Bootstrapper.
Structs
- Cache
Config cache - Configuration for the cache system.
- Cache
Config Builder - Builder for
CacheConfig. - Cache
Store Config cache - Configuration for the cache store backend.
- Cache
Store Config Builder - Builder for
CacheStoreConfig. - Cache
Url cache - A URL for caches.
- Database
Config db - The configuration for the database.
- Database
Config Builder - Builder for
DatabaseConfig. - Database
Url db - A URL for the database.
- Email
Config email - Configuration for the email system.
- Email
Config Builder - Builder for
EmailConfig. - Email
Transport Config email - Configuration structure for email transport settings.
- Email
Transport Config Builder - Builder for
EmailTransportConfig. - Email
Url email - A URL for email services.
- Live
Reload Middleware Config - The configuration for the live reload middleware.
- Live
Reload Middleware Config Builder - Builder for
LiveReloadMiddlewareConfig. - Middleware
Config - The configuration for the middlewares.
- Middleware
Config Builder - Builder for
MiddlewareConfig. - Project
Config - The configuration for a project.
- Project
Config Builder - Builder for
ProjectConfig. - Secret
Key - A secret key.
- Session
Middleware Config - The configuration for the session middleware.
- Session
Middleware Config Builder - Builder for
SessionMiddlewareConfig. - Session
Store Config - The configuration for the session store.
- Session
Store Config Builder - Builder for
SessionStoreConfig. - Static
Files Config - The configuration for the static files. The configuration for serving static files. This configuration controls how static files (like CSS, JavaScript, images, etc.) are served by the application. It allows you to customize the URL prefix, caching behavior, and URL rewriting strategy for static assets.
- Static
Files Config Builder - Builder for
StaticFilesConfig.
Enums
- Auth
Backend Config - The configuration for the authentication backend.
- Cache
Store Type Config cache - The type of cache store backend to use.
- Cache
Type cache - A structure that holds the type of Cache.
- Email
Transport Type Config email - The type of email transport backend to use.
- Expiry
- Session expiry configuration.
The
Expiryattribute of a cookie determines its lifetime. When not explicitly configured, cookies default toOnSessionEndbehavior. - Parse
Cache Type Error - An error returned when parsing a
CacheTypefrom a string. - Same
Site - The
SameSiteattribute of a cookie determines how strictly browsers send cookies on cross-site requests. When not explicitly configured, it defaults toStrict, which provides the most restrictive security posture. - Session
Store Type Config - The configuration for the session store type.
- Static
Files Path Rewrite Mode - Configuration for the URL rewriting of static files.
- Timeout
- Expiration policy for cached values.