pub enum ForeignKey<T: Model> {
PrimaryKey(T::PrimaryKey),
Model(Box<T>),
}db only.Expand description
A foreign key to another model.
Internally, this is represented either as a primary key (in case the model has not been retrieved from the database) or as the model itself.
Examples
use cot::db::{Auto, Database, ForeignKey, Model, model};
use cot::response::Response;
#[model]
struct MyModel {
#[model(primary_key)]
id: Auto<i32>,
user: ForeignKey<User>,
}
#[model]
struct User {
#[model(primary_key)]
id: Auto<i32>,
}
async fn index(db: Database) -> cot::Result<Response> {
let mut user = User { id: Auto::auto() };
user.save(&db).await?;
let mut my_model = MyModel {
id: Auto::auto(),
user: ForeignKey::from(user),
};
my_model.save(&db).await?;
// ...
}Variants
PrimaryKey(T::PrimaryKey)
The primary key of the referenced model; used when the model has not been retrieved from the database yet or when it’s unnecessary to store the entire model instance.
Model(Box<T>)
The referenced model.
Implementations
Sourceimpl<T: Model> ForeignKey<T>
impl<T: Model> ForeignKey<T>
Sourcepub fn primary_key(&self) -> &T::PrimaryKey
pub fn primary_key(&self) -> &T::PrimaryKey
Returns the primary key of the referenced model.
Sourcepub fn model(&self) -> Option<&T>
pub fn model(&self) -> Option<&T>
Returns the model, if it has been stored in this ForeignKey
instance, or None otherwise.
Sourcepub fn unwrap(self) -> T
pub fn unwrap(self) -> T
Unwrap the foreign key, returning the model.
Panics
Panics if the model has not been stored in this ForeignKey instance.
Sourcepub async fn get<DB: DatabaseBackend>(&mut self, db: &DB) -> Result<&T>
pub async fn get<DB: DatabaseBackend>(&mut self, db: &DB) -> Result<&T>
Retrieve the model from the database, if needed, and return it.
If the model has already been retrieved, this method will return it.
This method will replace the primary key with the model instance if
the primary key is stored in this ForeignKey instance.
Errors
Returns a DatabaseError::ForeignKeyNotFound error if the model
could not be found in the database.
Returns an error if there was a problem communicating with the database.