pub struct Query<T> { /* private fields */ }Available on crate feature
db only.Expand description
A query that can be executed on a database. Can be used to filter, update, or delete rows.
Example
use cot::db::model;
use cot::db::query::Query;
#[model]
struct User {
#[model(primary_key)]
id: i32,
name: String,
age: i32,
}
let query = Query::<User>::new();Implementations
Sourceimpl<T: Model> Query<T>
impl<T: Model> Query<T>
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new query.
Example
use cot::db::model;
use cot::db::query::Query;
#[model]
struct User {
#[model(primary_key)]
id: i32,
name: String,
age: i32,
}
let query = Query::<User>::new();Sourcepub fn filter(&mut self, filter: Expr) -> &mut Self
pub fn filter(&mut self, filter: Expr) -> &mut Self
Set the filter expression for the query.
Example
use cot::db::model;
use cot::db::query::{Expr, Query};
#[model]
struct User {
#[model(primary_key)]
id: i32,
name: String,
age: i32,
}
let query = Query::<User>::new().filter(Expr::eq(Expr::field("name"), Expr::value("John")));Sourcepub fn limit(&mut self, limit: u64) -> &mut Self
pub fn limit(&mut self, limit: u64) -> &mut Self
Set the limit for the query.
Example
use cot::db::model;
use cot::db::query::{Expr, Query};
#[model]
struct User {
#[model(primary_key)]
id: i32,
name: String,
age: i32,
}
let query = Query::<User>::new().limit(10);Sourcepub fn offset(&mut self, offset: u64) -> &mut Self
pub fn offset(&mut self, offset: u64) -> &mut Self
Set the offset for the query.
Example
use cot::db::model;
use cot::db::query::{Expr, Query};
#[model]
struct User {
#[model(primary_key)]
id: i32,
name: String,
age: i32,
}
let query = Query::<User>::new().offset(10);Sourcepub async fn delete<DB: DatabaseBackend>(
&self,
db: &DB,
) -> Result<StatementResult>
pub async fn delete<DB: DatabaseBackend>( &self, db: &DB, ) -> Result<StatementResult>