pub struct DynErrorPageHandler { /* private fields */ }Expand description
A type-erased wrapper around an error page handler.
This struct allows storing different types of error page handlers in a
homogeneous collection or service. It implements Clone and can be
used with Cot’s error handling infrastructure.
Implementations
Sourceimpl DynErrorPageHandler
impl DynErrorPageHandler
Sourcepub fn new<HandlerParams, H>(handler: H) -> Self
pub fn new<HandlerParams, H>(handler: H) -> Self
Creates a new DynErrorPageHandler from a concrete error page handler.
This method wraps a concrete error page handler in a type-erased
wrapper, allowing it to be used in
crate::project::Project::error_handler.
Examples
use cot::Project;
use cot::error::handler::{DynErrorPageHandler, RequestError};
use cot::html::Html;
use cot::response::IntoResponse;
struct MyProject;
impl Project for MyProject {
fn error_handler(&self) -> DynErrorPageHandler {
DynErrorPageHandler::new(error_handler)
}
}
// This function automatically implements ErrorPageHandler
async fn error_handler(error: RequestError) -> impl IntoResponse {
Html::new(format!("An error occurred: {error}")).with_status(error.status_code())
}Trait Implementations
Sourceimpl Clone for DynErrorPageHandler
impl Clone for DynErrorPageHandler
Sourcefn clone(&self) -> DynErrorPageHandler
fn clone(&self) -> DynErrorPageHandler
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DynErrorPageHandler
impl Debug for DynErrorPageHandler
Sourceimpl Service<Request<Body>> for DynErrorPageHandler
impl Service<Request<Body>> for DynErrorPageHandler
Sourcetype Future = Pin<Box<dyn Future<Output = Result<<DynErrorPageHandler as Service<Request<Body>>>::Response, Error>> + Send>>
type Future = Pin<Box<dyn Future<Output = Result<<DynErrorPageHandler as Service<Request<Body>>>::Response, Error>> + Send>>
The future response value.