FormFieldValidationError

Enum FormFieldValidationError 

#[non_exhaustive]
pub enum FormFieldValidationError { Required, MaximumLengthExceeded { max_length: u32, }, MinimumLengthNotMet { min_length: u32, }, MinimumValueNotMet { min_value: String, }, MaximumValueExceeded { max_value: String, }, AmbiguousDateTime { datetime: NaiveDateTime, }, NonExistentLocalDateTime { datetime: NaiveDateTime, timezone: Tz, }, BooleanRequiredToBeTrue, InvalidValue(String), FormFieldValueError(FormFieldValueError), Custom(Cow<'static, str>), }
An error that can occur when validating a form field.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Required

The field is required.



MaximumLengthExceeded

The field value is too long.

Fields

max_length: u32

The maximum length of the field.



MinimumLengthNotMet

The field value is too short.

Fields

min_length: u32

The minimum length of the field.



MinimumValueNotMet

The field value is below the permitted minimum.

Fields

min_value: String

The minimum permitted value.



MaximumValueExceeded

The field value exceeds the permitted maximum.

Fields

max_value: String

The maximum permitted value.



AmbiguousDateTime

The field value is an ambiguous datetime.

Fields

datetime: NaiveDateTime

The ambiguous datetime value.



NonExistentLocalDateTime

The field value is a non-existent local datetime.

Fields

datetime: NaiveDateTime

The non-existent local datetime value.

timezone: Tz

The timezone in which the datetime was specified.



BooleanRequiredToBeTrue

The field value is required to be true.



InvalidValue(String)

The field value is invalid.



FormFieldValueError(FormFieldValueError)

An error occurred while getting the field value.



Custom(Cow<'static, str>)

Custom error with a given message.

Implementations

Source

impl FormFieldValidationError

pub fn invalid_value<T: Into<String>>(value: T) -> Self

Creates a new FormFieldValidationError for an invalid value of a field.

pub fn maximum_length_exceeded(max_length: u32) -> Self

Creates a new FormFieldValidationError for a field value that is too long.

pub fn minimum_length_not_met(min_length: u32) -> Self

Creates a new FormFieldValidationError for a field value that is too short.

pub fn minimum_value_not_met<T: Display>(min_value: T) -> Self

Creates a new FormFieldValidatorErrorfor a field value below the permitted minimum value.

pub fn maximum_value_exceeded<T: Display>(max_value: T) -> Self

Creates a new FormFieldValidationError for a field value that exceeds the permitted maximum value

pub fn ambiguous_datetime(datetime: NaiveDateTime) -> Self

Creates a new FormFieldValidationError for an ambiguous datetime.

pub fn non_existent_local_datetime( datetime: NaiveDateTime, timezone: Tz, ) -> Self

Creates a new FormFieldValidationError for a non-existent local datetime.

pub const fn from_string(message: String) -> Self

Creates a new FormFieldValidationError from a String.

pub const fn from_static(message: &'static str) -> Self

Creates a new FormFieldValidationError from a static string.