Enum FormFieldValidationError

pub enum FormFieldValidationError {
    Required,
    MaximumLengthExceeded {
        max_length: u32,
    },
    BooleanRequiredToBeTrue,
    InvalidValue(String),
    Custom(Cow<'static, str>),
}
An error that can occur when validating a form field.

Variants



Required

The field is required.



MaximumLengthExceeded

The field value is too long.

Fields

max_length: u32

The maximum length of the field.



BooleanRequiredToBeTrue

The field value is required to be true.



InvalidValue(String)

The field value is invalid.



Custom(Cow<'static, str>)

Custom error with given message.

Implementations

Source

impl FormFieldValidationError

pub fn invalid_value<T: Into<String>>(value: T) -> Self

Creates a new FormFieldValidationError for an invalid value of a field.

pub fn maximum_length_exceeded(max_length: u32) -> Self

Creates a new FormFieldValidationError for a field value that is too long.

pub const fn from_string(message: String) -> Self

Creates a new FormFieldValidationError from a String.

pub const fn from_static(message: &'static str) -> Self

Creates a new FormFieldValidationError from a static string.