pub struct Json<D>(pub D);json only.Expand description
A type that represents JSON content.
Note that this is just a newtype wrapper around data and does not provide any content validation. It is primarily useful as a request extractor and response type for REST-ful endpoints.
Examples
use cot::json::Json;
let Json(data) = Json("content");
assert_eq!(data, "content");Tuple Fields
0: DTrait Implementations
Sourceimpl<D: JsonSchema> ApiOperationPart for Json<D>
Available on crate feature openapi only.
impl<D: JsonSchema> ApiOperationPart for Json<D>
openapi only.Sourcefn modify_api_operation(
operation: &mut Operation,
_route_context: &RouteContext<'_>,
schema_generator: &mut SchemaGenerator,
)
fn modify_api_operation( operation: &mut Operation, _route_context: &RouteContext<'_>, schema_generator: &mut SchemaGenerator, )
Sourceimpl<S: JsonSchema> ApiOperationResponse for Json<S>
Available on crate feature openapi only.
impl<S: JsonSchema> ApiOperationResponse for Json<S>
openapi only.Sourcefn api_operation_responses(
_operation: &mut Operation,
_route_context: &RouteContext<'_>,
schema_generator: &mut SchemaGenerator,
) -> Vec<(Option<StatusCode>, Response)>
fn api_operation_responses( _operation: &mut Operation, _route_context: &RouteContext<'_>, schema_generator: &mut SchemaGenerator, ) -> Vec<(Option<StatusCode>, Response)>
Sourceimpl<D: DeserializeOwned> FromRequest for Json<D>
Extractor that gets the request body as JSON and deserializes it into a type
T implementing serde::de::DeserializeOwned.
impl<D: DeserializeOwned> FromRequest for Json<D>
Extractor that gets the request body as JSON and deserializes it into a type
T implementing serde::de::DeserializeOwned.
The content type of the request must be application/json.
Errors
Throws an error if the content type is not application/json.
Throws an error if the request body could not be read.
Throws an error if the request body could not be deserialized - either
because the JSON is invalid or because the deserialization to the target
structure failed.
Example
use cot::RequestHandler;
use cot::json::Json;
use cot::test::TestRequestBuilder;
use serde::{Deserialize, Serialize};
#[derive(Serialize, Deserialize)]
struct MyData {
hello: String,
}
async fn my_handler(Json(data): Json<MyData>) -> Json<MyData> {
Json(data)
}
let request = TestRequestBuilder::get("/")
.json(&MyData {
hello: "world".to_string(),
})
.build();
assert_eq!(
my_handler
.handle(request)
.await?
.into_body()
.into_bytes()
.await?,
"{\"hello\":\"world\"}"
);Sourceasync fn from_request(head: &RequestHead, body: Body) -> Result<Self>
async fn from_request(head: &RequestHead, body: Body) -> Result<Self>
Sourceimpl<D: Serialize> IntoResponse for Json<D>
impl<D: Serialize> IntoResponse for Json<D>
Sourcefn into_response(self) -> Result<Response>
fn into_response(self) -> Result<Response>
Create a new JSON response.
This creates a new Response object with a content type of
application/json and given body.
Examples
use std::collections::HashMap;
use cot::json::Json;
use cot::response::IntoResponse;
let data = HashMap::from([("hello", "world")]);
let json = Json(data);
let response = json.into_response();Sourcefn with_header<K, V>(self, key: K, value: V) -> WithHeader<Self>
fn with_header<K, V>(self, key: K, value: V) -> WithHeader<Self>
Sourcefn with_content_type<V>(self, content_type: V) -> WithContentType<Self>
fn with_content_type<V>(self, content_type: V) -> WithContentType<Self>
Content-Type header. Read moreSourcefn with_status(self, status: StatusCode) -> WithStatus<Self>where
Self: Sized,
fn with_status(self, status: StatusCode) -> WithStatus<Self>where
Self: Sized,
Sourcefn with_body(self, body: impl Into<Body>) -> WithBody<Self>where
Self: Sized,
fn with_body(self, body: impl Into<Body>) -> WithBody<Self>where
Self: Sized,
Sourcefn with_extension<T>(self, extension: T) -> WithExtension<Self, T>
fn with_extension<T>(self, extension: T) -> WithExtension<Self, T>
Sourceimpl<D: Ord> Ord for Json<D>
impl<D: Ord> Ord for Json<D>
Sourceimpl<D: PartialOrd> PartialOrd for Json<D>
impl<D: PartialOrd> PartialOrd for Json<D>
impl<D: Copy> Copy for Json<D>
impl<D: Eq> Eq for Json<D>
impl<D> StructuralPartialEq for Json<D>