pub async fn run(
bootstrapper: Bootstrapper<Initialized>,
address_str: &str,
) -> Result<()>Expand description
Runs the Cot project on the given address.
This function takes a Cot project and an address string and runs the project on the given address.
Errors
This function returns an error if the server fails to start.