pub struct RootHandlerBuilder<S = RouterService, SE = DynErrorPageHandler> { /* private fields */ }Expand description
A helper struct to build the root handler for the project.
This is mainly useful for attaching middlewares to the project.
Examples
use cot::Project;
use cot::middleware::LiveReloadMiddleware;
use cot::project::{MiddlewareContext, RootHandler, RootHandlerBuilder};
struct MyProject;
impl Project for MyProject {
fn middlewares(
&self,
handler: RootHandlerBuilder,
context: &MiddlewareContext,
) -> RootHandler {
handler
.middleware(LiveReloadMiddleware::from_context(context))
.build()
}
}Implementations
Sourceimpl<RootService, ErrorHandlerService> RootHandlerBuilder<RootService, ErrorHandlerService>
impl<RootService, ErrorHandlerService> RootHandlerBuilder<RootService, ErrorHandlerService>
Sourcepub fn middleware<M>(
self,
middleware: M,
) -> RootHandlerBuilder<WrappedMiddleware<M, RootService>, WrappedMiddleware<M, ErrorHandlerService>>
pub fn middleware<M>( self, middleware: M, ) -> RootHandlerBuilder<WrappedMiddleware<M, RootService>, WrappedMiddleware<M, ErrorHandlerService>>
Adds middleware to the project.
This method is used to add middleware to the project. The middleware will be applied to all routes in the project.
Examples
use cot::Project;
use cot::middleware::LiveReloadMiddleware;
use cot::project::{MiddlewareContext, RootHandler, RootHandlerBuilder};
struct MyProject;
impl Project for MyProject {
fn middlewares(
&self,
handler: RootHandlerBuilder,
context: &MiddlewareContext,
) -> RootHandler {
handler
.middleware(LiveReloadMiddleware::from_context(context))
.build()
}
}Sourcepub fn main_handler_middleware<M>(
self,
middleware: M,
) -> RootHandlerBuilder<WrappedMiddleware<M, RootService>, ErrorHandlerService>where
M: Layer<RootService>,
pub fn main_handler_middleware<M>(
self,
middleware: M,
) -> RootHandlerBuilder<WrappedMiddleware<M, RootService>, ErrorHandlerService>where
M: Layer<RootService>,
Adds middleware only to the main request handler.
This method is used to add middleware that should only be applied to the main request handler, not to the error handler. This is useful when you have middleware that should only run for successful requests, such as logging middleware that should not interfere with error handling.
Examples
use cot::Project;
use cot::middleware::LiveReloadMiddleware;
use cot::project::{MiddlewareContext, RootHandler, RootHandlerBuilder};
struct MyProject;
impl Project for MyProject {
fn middlewares(
&self,
handler: RootHandlerBuilder,
context: &MiddlewareContext,
) -> RootHandler {
handler
.main_handler_middleware(LiveReloadMiddleware::from_context(context))
.build()
}
}Sourcepub fn error_handler_middleware<M>(
self,
middleware: M,
) -> RootHandlerBuilder<RootService, WrappedMiddleware<M, ErrorHandlerService>>where
M: Layer<ErrorHandlerService>,
pub fn error_handler_middleware<M>(
self,
middleware: M,
) -> RootHandlerBuilder<RootService, WrappedMiddleware<M, ErrorHandlerService>>where
M: Layer<ErrorHandlerService>,
Adds middleware only to the error handler.
This method is used to add middleware that should only be applied to the error handler, not to the main request handler. This is useful when you have middleware that should only run when handling errors, such as error reporting middleware or middleware that modifies error responses.
Examples
use cot::Project;
use cot::project::{MiddlewareContext, RootHandler, RootHandlerBuilder};
use cot::static_files::StaticFilesMiddleware;
struct MyProject;
impl Project for MyProject {
fn middlewares(
&self,
handler: RootHandlerBuilder,
context: &MiddlewareContext,
) -> RootHandler {
handler
.error_handler_middleware(StaticFilesMiddleware::from_context(context))
.build()
}
}Sourcepub fn build(self) -> RootHandler
pub fn build(self) -> RootHandler
Builds the root handler for the project.
Examples
use cot::Project;
use cot::middleware::LiveReloadMiddleware;
use cot::project::{MiddlewareContext, RootHandler, RootHandlerBuilder};
struct MyProject;
impl Project for MyProject {
fn middlewares(
&self,
handler: RootHandlerBuilder,
context: &MiddlewareContext,
) -> RootHandler {
handler
.middleware(LiveReloadMiddleware::from_context(context))
.build()
}
}Trait Implementations
Sourceimpl<S: Clone, SE: Clone> Clone for RootHandlerBuilder<S, SE>
impl<S: Clone, SE: Clone> Clone for RootHandlerBuilder<S, SE>
Sourcefn clone(&self) -> RootHandlerBuilder<S, SE>
fn clone(&self) -> RootHandlerBuilder<S, SE>
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl<S, SE> Debug for RootHandlerBuilder<S, SE>
impl<S, SE> Debug for RootHandlerBuilder<S, SE>
impl<S: Eq, SE: Eq> Eq for RootHandlerBuilder<S, SE>
impl<S, SE> StructuralPartialEq for RootHandlerBuilder<S, SE>