HTTP request type and helper methods.
Cot uses the Request type from the http crate
to represent incoming HTTP requests. However, it also provides a
RequestExt trait that contains various helper methods for working with
HTTP requests. These methods are used to access the application context,
project configuration, path parameters, and more. You probably want to have
a use statement for RequestExt in your code most of the time to be
able to use these functions:
use cot::request::RequestExt;Modules
- extractors
- Extractors for request data.
Structs
- Path
Params - Path parameters extracted from the request URL, and available as a map of strings.
- Path
Params Deserializer Error - An error that occurs when deserializing path parameters.
Traits
- Request
Ext - Extension trait for
http::Requestthat provides helper methods for working with HTTP requests.
Type Aliases
- Request
- HTTP request type.
- Request
Head - HTTP request head type.